@@ -1,4 +1,5 @@
 from datetime import date, datetime
+from decimal import Decimal
 from zoneinfo import ZoneInfo
 
 from django.test import TestCase
@@ -13,6 +14,7 @@ from edc_utils import (
     get_dob,
     get_safe_random_string,
 )
+from edc_utils.round_up import round_half_away_from_zero
 
 
 class TestUtils(TestCase):
@@ -136,3 +138,22 @@ class TestUtils(TestCase):
     def get_datetime_from_env(self):
         dt = datetime(1990, 5, 2, 0, 0, tzinfo=ZoneInfo("Africa/Gaborone"))
         self.assertEqual(dt, get_datetime_from_env(1990, 5, 2, 0, 0, 0, "Africa/Gaborone"))
+
+    def test_round_up(self):
+        self.assertEqual(round_half_away_from_zero(1.5, 0), 2)
+        self.assertEqual(round_half_away_from_zero(1.55, 1), 1.6)
+        self.assertEqual(round_half_away_from_zero(1.54, 1), 1.5)
+        self.assertEqual(round_half_away_from_zero(1.555, 2), 1.56)
+        self.assertEqual(round_half_away_from_zero(1.555, 2), 1.56)
+
+        self.assertEqual(round_half_away_from_zero(-1.5, 0), -2)
+        self.assertEqual(round_half_away_from_zero(-1.55, 1), -1.6)
+        self.assertEqual(round_half_away_from_zero(-1.54, 1), -1.5)
+        self.assertEqual(round_half_away_from_zero(-1.555, 2), -1.56)
+        self.assertEqual(round_half_away_from_zero(-1.5554, 3), -1.555)
+
+        self.assertEqual(round_half_away_from_zero(Decimal("1.5"), 0), Decimal("2"))
+        self.assertEqual(round_half_away_from_zero(Decimal("1.55"), 1), Decimal("1.6"))
+        self.assertEqual(round_half_away_from_zero(Decimal("1.54"), 1), Decimal("1.5"))
+        self.assertEqual(round_half_away_from_zero(Decimal("1.555"), 2), Decimal("1.56"))
+        self.assertEqual(round_half_away_from_zero(Decimal("1.5554"), 3), Decimal("1.555"))
